@@ -141,6 +141,18 @@ def midday_ts(days_back: int = 0, ts: float = 0.) -> float:
                                  tzinfo=gettz(os.environ['TZ'])).timestamp() * 1000
 
 
+def midday_datetime_from_date(date: datetime.datetime) -> datetime.datetime:
+    """
+    Convert date to datetime with time being midday
+    :param date: datetime.date object
+    :return: datetime.datetime object
+    """
+    date_time = datetime.datetime.combine(date,
+                                          datetime.time(12, 0),
+                                          tzinfo=gettz(os.environ["TZ"]))
+    return date_time
+
+
 def midnight_ts(days_back: int = 0) -> float:
     """
     The 00:00 local time N days back
@@ -194,7 +206,7 @@ def benchmark(display_func):
         def wrapper(*args, **kwargs):
             start = time.perf_counter()
             res = func(*args, **kwargs)
-            display_func(f"{func.__name__} executed in {time.perf_counter() - start}s")
+            display_func(f"{func.__name__} executed in {time.perf_counter() - start:.3f}s")
             return res
 
         return wrapper
@@ -348,3 +360,4 @@ def convert_to_decimal(structure: dict) -> dict:
     return json.loads(json.dumps(convert_to_float(structure)),
                       parse_float=decimal.Decimal,
                       parse_int=decimal.Decimal)
+
